==> qtjambi-qt3drender-6.5.1-sources.jar: io/qt/qt3d/render/QShaderData.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Provides a way of specifying values of a Uniform Block or a shader structure</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qshaderdata.html">Qt3DRender::QShaderData</a></p>
 */
public class QShaderData extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QShaderData.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QShaderData(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QShaderData() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qshaderdata.html#QShaderData">Qt3DRender::QShaderData::QShaderData(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QShaderData(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QShaderData instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>QShaderData::propertyReader Returns the PropertyReaderInterfacePtr for this shader data</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qshaderdata.html#propertyReader">Qt3DRender::QShaderData::propertyReader()const</a></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable PropertyReaderInterface propertyReader(){
        return propertyReader_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.PropertyReaderInterface propertyReader_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qobject.html#event">QObject::event(QEvent*)</a></p>
     */
    @QtUninvokable
    public boolean event(io.qt.core.@Nullable QEvent event){
        return event_native_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @QtUninvokable
    private native boolean event_native_QEvent_ptr(long __this__nativeId, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QShaderData(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QShaderData(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QShaderData instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.5.2-sources.jar: io/qt/qt3d/render/QShaderData.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Provides a way of specifying values of a Uniform Block or a shader structure</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qshaderdata.html">Qt3DRender::QShaderData</a></code></p>
 */
public class QShaderData extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QShaderData.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QShaderData(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QShaderData() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qshaderdata.html#QShaderData">Qt3DRender::QShaderData::<wbr>QShaderData(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QShaderData(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QShaderData instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>QShaderData::propertyReader Returns the PropertyReaderInterfacePtr for this shader data</p>
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qshaderdata.html#propertyReader">Qt3DRender::QShaderData::<wbr>propertyReader()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable PropertyReaderInterface propertyReader(){
        return propertyReader_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.PropertyReaderInterface propertyReader_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qobject.html#event">QObject::<wbr>event(QEvent*)</a></code></p>
     */
    @QtUninvokable
    public boolean event(io.qt.core.@Nullable QEvent event){
        return event_native_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @QtUninvokable
    private native boolean event_native_QEvent_ptr(long __this__nativeId, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QShaderData(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QShaderData(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QShaderData instance, QDeclarativeConstructor constructor);
    
}
